"""init file for the 'hoppr.core_plugins.report_generator' module."""

from __future__ import annotations

from hoppr.core_plugins.report_generator.report_generator import Report, ReportGenerator

__all__ = ["Report", "ReportGenerator"]
